You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by hl...@apache.org on 2011/04/22 02:05:17 UTC

svn commit: r1095848 - /tapestry/tapestry5/trunk/build.gradle

Author: hlship
Date: Fri Apr 22 00:05:17 2011
New Revision: 1095848

URL: http://svn.apache.org/viewvc?rev=1095848&view=rev
Log:
TAP5-116: Set up to deploy to Apache Nexus (snapshots repository)

Modified:
    tapestry/tapestry5/trunk/build.gradle

Modified: tapestry/tapestry5/trunk/build.gradle
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/build.gradle?rev=1095848&r1=1095847&r2=1095848&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/build.gradle (original)
+++ tapestry/tapestry5/trunk/build.gradle Fri Apr 22 00:05:17 2011
@@ -1,7 +1,7 @@
 description = "Apache Tapestry 5 Project"
 
-if (!project.hasProperty('deployUserName')) deployUserName = '*UNSET-USERNAME*'
-if (!project.hasProperty('deployPassword')) deployPassword = '*UNSET-PASSWORD*'
+if (!project.hasProperty('apacheDeployUserName')) apacheDeployUserName = '*UNSET-USERNAME*'
+if (!project.hasProperty('apacheDeployPassword')) apacheDeployPassword = '*UNSET-PASSWORD*'
 
 
 jettyVersion = '7.0.0.v20091005'
@@ -52,7 +52,7 @@ subprojects {
     dependencies {
         groovy "org.codehaus.groovy:groovy-all:1.7.4"
         
-        deployerJars "org.apache.maven.wagon:wagon-ftp:1.0-beta-2"        
+        deployerJars "org.apache.maven.wagon:wagon-http-lightweight:1.0-beta-6"
     }
     
     test {
@@ -73,14 +73,13 @@ subprojects {
     artifacts {
        archives sourcesJar
     }    
-
     
     uploadArchives {
         repositories.mavenDeployer {
             configuration = configurations.deployerJars
-            // deployUserName and deployPassword should be specified in ~/.gradle/gradle.properties
-            snapshotRepository(url: "ftp://howardlewisship.com/snapshot-repository") {
-              authentication(userName: deployUserName, password: deployPassword)
+            // apacheDeployUserName and apacheDeployPassword should be specified in ~/.gradle/gradle.properties
+            snapshotRepository(url: "https://repository.apache.org/content/repositories/snapshots/") {
+              authentication(userName: apacheDeployUserName, password: apacheDeployPassword)
             }
             
         }